/* The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Eric Hodel's <drbrain@segment7.net> code.
 * 
 * The Initial Developer of the Original Code is Eric Hodel.
 * Portions created by Eric Hodel are Copyright (C) 2001 Eric
 * Hodel. All Rights Reserved.
 * 
 * Other Contributors:
 *      Christopher Hoess <choess@force.stwing.upenn.edu>
 *      Tim Taylor <tim@tool-man.org>
 */

/*
 * LanguageDictionary is a Singleton for looking up a language name
 * given its language code.
 */
function LanguageDictionary() {
  this.dictionary = null;

  this.lookupLanguageName = function(languageCode) {
    if (this.getDictionary()[languageCode])
      return this.getDictionary()[languageCode];
    else
      // XXX: handle non-standard language code's per
      //    hixie's spec (see bug 2800)
      return "";
  }

  this.getDictionary = function() {
    if (this.dictionary == null)
      this.dictionary = createDictionary();

    return this.dictionary;
  }

  function createDictionary() {
    var dictionary = new Array();

    var e = getLanguageNames().getSimpleEnumeration();
    while (e.hasMoreElements()) {
      var property = e.getNext();
      property = property.QueryInterface(
          Components.interfaces.nsIPropertyElement);
      dictionary[property.getKey()] = property.getValue();
    }

    return dictionary;
  }

  function getLanguageNames() {
    return srGetStrBundle(
        "chrome://global/locale/languageNames.properties");
  }
}
const languageDictionary = new LanguageDictionary();
